import request from '@/utils/request'

// 查询图层管理列表
export function listLayers(query) {
  return request({
    url: '/system/layers/list',
    method: 'get',
    params: query
  })
}

// 查询图层管理详细
export function getLayers(id) {
  return request({
    url: '/system/layers/' + id,
    method: 'get'
  })
}

// 新增图层管理
export function addLayers(data) {
  return request({
    url: '/system/layers',
    method: 'post',
    data: data
  })
}

// 修改图层管理
export function updateLayers(data) {
  return request({
    url: '/system/layers',
    method: 'put',
    data: data
  })
}

// 删除图层管理
export function delLayers(id) {
  return request({
    url: '/system/layers/' + id,
    method: 'delete'
  })
}
// tif转图片
export function tifConvert(id) {
  return request({
    url: '/pipe/layers/tifConvert/' + id,
    method: 'post',
    baseURL: "/map-api"
  })
}
//图层授权用户
export function authUserPut(data) {
  return request({
    url: 'system/layers/authUser',
    method: 'put',
    data
  })
}
//获取授权用户
export function authUserGet(id) {
  return request({
    url: '/system/layers/authUser/' + id,
    method: 'get',

  })
}
